@@ -64,6 +64,9 @@ class ImageStore(object):
 
         :param **kwargs: The columns key/value of the row.
 
+        :rtype: gtk.TreeIter
+        :return: the iter of the inserted value.
+
         >>> image_store = ImageStore()
         >>> image_store.length
         0
@@ -71,6 +74,7 @@ class ImageStore(object):
         ...     input_file="/tmp/foobar.png",
         ...     output_file="/tmp/foobar.opti.png",
         ... )
+        <Gtk.TreeIter object ...>
         >>> image_store.length
         1
         >>> image_store.append(foo="bar")
@@ -90,12 +94,14 @@ class ImageStore(object):
 
         iter_ = self.gtk_list_store.append(row)
         self.update(iter_, **kwargs)
+        return iter_
 
     def clear(self):
         """Clears the store.
 
         >>> image_store = ImageStore()
         >>> image_store.append()
+        <Gtk.TreeIter object ...>
         >>> image_store.length
         1
         >>> image_store.clear()
@@ -114,6 +120,7 @@ class ImageStore(object):
 
         >>> image_store = ImageStore()
         >>> image_store.append()
+        <Gtk.TreeIter object ...>
         >>> image_store.get(0)
         {...}
         >>> image_store.get(1)
@@ -155,6 +162,7 @@ class ImageStore(object):
 
         >>> image_store = ImageStore()
         >>> image_store.append()
+        <Gtk.TreeIter object ...>
         >>> image_store.length
         1
         >>> image_store.remove_at_index(0)
@@ -174,7 +182,7 @@ class ImageStore(object):
     def update(self, index, **kwargs):
         """Updates a row.
 
-        :param int,gtk.TreeIter index: The index of the row.
+        :param int,Gtk.TreeIter index: The index of the row.
         :param **kwargs: The columns key/value of the row.
 
         >>> image_store = ImageStore()
@@ -183,6 +191,7 @@ class ImageStore(object):
         ...     output_file="aaa.png",
         ...     use_output_pattern=False,
         ... )
+        <Gtk.TreeIter object ...>
         >>> image_store.get(0)["output_file"]
         '...aaa.png'
         >>> image_store.update(0, output_file="bbb.png")
@@ -367,7 +376,7 @@ class ImageStore(object):
     def reset_status(self, index):
         """Reset the status of the image at given index.
 
-        :param int,gtk.TreeIter index: The index of the row.
+        :param int,Gtk.TreeIter index: The index of the row.
 
         >>> image_store = ImageStore()
         >>> image_store.append(
@@ -375,6 +384,7 @@ class ImageStore(object):
         ...     input_size=1024,
         ...     output_size=1024,
         ... )
+        <Gtk.TreeIter object ...>
         >>> image_store.get(0)["status"]
         3
         >>> image_store.get(0)["output_size"]
